summaryrefslogtreecommitdiffhomepage
path: root/Private/KernelKit/FileManager.hpp
diff options
context:
space:
mode:
authoramlal <amlal@el-mahrouss-logic.com>2024-03-16 14:22:21 +0100
committeramlal <amlal@el-mahrouss-logic.com>2024-03-16 14:22:21 +0100
commit55059428bfd6a18451bc1ed3ee64e7bb04c395cd (patch)
tree02dd524a2249111e30d2208fd700fa72e31182db /Private/KernelKit/FileManager.hpp
parent8f9b5e08f53f6e49a1f4c6b20e17c54298da9c44 (diff)
HCR-14: See below.
- Pretty big modifications, add kernel mouse. Signed-off-by: amlal <amlal@el-mahrouss-logic.com>
Diffstat (limited to 'Private/KernelKit/FileManager.hpp')
-rw-r--r--Private/KernelKit/FileManager.hpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/Private/KernelKit/FileManager.hpp b/Private/KernelKit/FileManager.hpp
index 3d986ddc..a00476bd 100644
--- a/Private/KernelKit/FileManager.hpp
+++ b/Private/KernelKit/FileManager.hpp
@@ -50,18 +50,18 @@ typedef VoidPtr NodePtr;
@brief Filesystem Manager Interface class
@brief Used to provide common I/O for a specific filesystem.
*/
-class IFilesystemManager {
+class FilesystemManagerInterface {
public:
- IFilesystemManager() = default;
- virtual ~IFilesystemManager() = default;
+ FilesystemManagerInterface() = default;
+ virtual ~FilesystemManagerInterface() = default;
public:
- HCORE_COPY_DEFAULT(IFilesystemManager);
+ HCORE_COPY_DEFAULT(FilesystemManagerInterface);
public:
- static bool Mount(IFilesystemManager *pMount);
- static IFilesystemManager *Unmount();
- static IFilesystemManager *GetMounted();
+ static bool Mount(FilesystemManagerInterface *pMount);
+ static FilesystemManagerInterface *Unmount();
+ static FilesystemManagerInterface *GetMounted();
public:
virtual NodePtr Create(_Input const char *path) = 0;
@@ -91,9 +91,9 @@ class IFilesystemManager {
#ifdef __FSKIT_NEWFS__
/**
* @brief Based of IFilesystemManager, takes care of managing NewFS disks.
*/
-class NewFilesystemManager final : public IFilesystemManager {
+class NewFilesystemManager final : public FilesystemManagerInterface {
public:
explicit NewFilesystemManager();
~NewFilesystemManager() override;
@@ -158,7 +158,7 @@ class NewFilesystemManager final : public IFilesystemManager {
* @tparam Encoding file encoding (char, wchar_t...)
* @tparam FSClass Filesystem contract who takes care of it.
*/
-template <typename Encoding = char, typename FSClass = IFilesystemManager>
+template <typename Encoding = char, typename FSClass = FilesystemManagerInterface>
class FileStream final {
public:
explicit FileStream(const Encoding *path, const Encoding *restrict_type);
@@ -91,9 +91,9 @@ class IFilesystemManager {
#ifdef __FSKIT_NEWFS__
/**
- * @brief Based of IFilesystemManager, takes care of managing NewFS disks.
+ * @brief Based of FilesystemManagerInterface, takes care of managing NewFS disks.
*/